# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# TODO: Add the following buildreqs/possibly reqs when available
#BuildRequires:	perl(Authen::NTLM)
#BuildRequires:	perl(Authen::SASL)
#BuildRequires:	perl(Digest::HMAC_MD5)

Name:		perl-Mail-IMAPClient
Version:	3.43
Release:	7.%{__distinit}%{__distvers}
Summary:	An IMAP Client API
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Mail-IMAPClient
Source0:	https://cpan.metacpan.org/modules/by-module/Mail/Mail-IMAPClient-%{version}.tar.gz
Patch0:		Mail-IMAPClient-3.43-UTF8.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(version)
BuildRequires:	sed
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Compress::Zlib)
BuildRequires:	perl(constant)
BuildRequires:	perl(Digest::MD5)
BuildRequires:	perl(Errno)
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(IO::Select)
BuildRequires:	perl(IO::Socket)
BuildRequires:	perl(IO::Socket::IP)
BuildRequires:	perl(IO::Socket::SSL)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(MIME::Base64)
BuildRequires:	perl(overload)
BuildRequires:	perl(Parse::RecDescent)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(base)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Pod) >= 1.00
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Compress::Zlib)
Requires:	perl(Digest::MD5)
Requires:	perl(IO::Socket::IP)
Requires:	perl(IO::Socket::SSL)

%description
This module provides perl routines that simplify a sockets connection 
to and an IMAP conversation with an IMAP server. 

%prep
%setup -q -n Mail-IMAPClient-%{version}

# Fix shellbangs in examples
sed -i 's#/usr/local/bin/perl#/usr/bin/perl#' examples/*.pl

# Turn off exec bits in examples to avoid docfile dependencies
chmod -c -x examples/*.pl

# Recode docs as UTF-8
%patch -P 0

%build
# the extended tests cannot be run without an IMAP server
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes README examples/
%{perl_vendorlib}/Mail/
%{_mandir}/man3/Mail::IMAPClient.3*
%{_mandir}/man3/Mail::IMAPClient::BodyStructure.3*
%{_mandir}/man3/Mail::IMAPClient::BodyStructure::Parse.3*
%{_mandir}/man3/Mail::IMAPClient::MessageSet.3*
%{_mandir}/man3/Mail::IMAPClient::Thread.3*

%changelog
* Tue Jul 18 2023 Paul Howarth <paul@city-fan.org> - 3.43-7
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Tue Feb 16 2021 Paul Howarth <paul@city-fan.org> - 3.43-1
- Update to 3.43
  - Admin: update copyright, move from rt.cpan.org (retired) to GitHub
  - compress: Readmethod: avoid false-positive EOF (CPAN RT#132720)
  - Parsing headers failed under special condition (CPAN RT#129920)
  - Avoid cyclic reference on ->compress (CPAN RT#132654)
  - append_string could fail to match APPENDUID in response (CPAN RT#132380)
  - Allow for undocumented BODYSTRUCTURE extensions (CPAN RT#133496)
- Use IO::Socket::IP unconditionally

* Mon Feb 25 2019 Paul Howarth <paul@city-fan.org> - 3.42-1
- Update to 3.42
  - has_capability() changes in 3.41 broke imap4rev1() (CPAN RT#128595)
  - Updated http:// to https:// URLs for referenced resources
  - Updated copyright for 2019

* Thu Feb 21 2019 Paul Howarth <paul@city-fan.org> - 3.41-1
- Update to 3.41
  - unseen(), messages() and related POD cleanup (CPAN RT#128220)
  - parse_message() minor code/POD cleanup (CPAN RT#128264)
  - Verb missing in messages() POD (CPAN RT#128215)
  - Simplify capability handling via has_capability enhancements
    (CPAN RT#127271)
    - has_capability() success returns(true) with server response data, not
      always '1'
    - Enhanced t/capability.t test cases
    - Updated POD for capability() and has_capability()
  - Use of IO::Socket::IP led to connect(empty args) regression
    (CPAN RT#122373)
  - Fix minor POD typo for search() (CPAN RT#128127)
  - folders()/subscribed() remove mailboxes with \Noselect attribute
  - fetch_hash() remove quotes around header names (seen with outlook.com)
  - Use first over grep for minor efficiency gains
  - Other minor POD cleanup

* Thu Dec  6 2018 Paul Howarth <paul@city-fan.org> - 3.40-1
- Update to 3.40
  - Support IPv6 by using IO::Socket::IP over IO::Socket::INET (CPAN RT#122373)
  - flags() undef value as an ARRAY reference on a bogus message
    (CPAN RT#127103)
  - Update examples/populate_mailbox.pl timegm usage (CPAN RT#124523)
  - t/capability.t: Added first set of tests
  - t/quota.t: Minor fix when tests skipped
- Switch upstream from search.cpan.org to metacpan.org

* Fri Apr 27 2018 Paul Howarth <paul@city-fan.org> - 3.39-4
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Mon Feb  6 2017 Paul Howarth <paul@city-fan.org> - 3.39-1
- Update to 3.39
  - Fix uninitialized value via fetch_hash (CPAN RT#115726)
  - Improve error reporting on failed TLS connections (CPAN RT#119523)
  - Document noop() (CPAN RT#114904)
  - Never retry DONE (CPAN RT#97718)
  - _imap_command() new doretry => 0|1 option to suppress/allow retry
  - Updated copyright for 2017

* Thu Sep  1 2016 Paul Howarth <paul@city-fan.org> - 3.38-2
- BR: perl-generators where available
- Simplify find command using -delete

* Tue Feb  9 2016 Paul Howarth <paul@city-fan.org> - 3.38-1
- Update to 3.38
  - Redact credentials via debug if !Showcredentials (CPAN RT#107592)
  - Fix failure to quote password values (regression introduced in 3.36 via
    fix for CPAN RT#100601) (CPAN RT#110273)
  - Allow getquota("") (CPAN RT#107593)
  - *Quote() now returns qq("") for defined but empty values
  - Fix folders_hash() docs and usage in is_parent() (CPAN RT#107011)
  - Split UID EXPUNGE with a large sequence set (CPAN RT#106500)
  - Added t/quota.t and t/lib/MyTest.pm for testing
  - Updated copyright for 2016

* Mon Aug 17 2015 Paul Howarth <paul@city-fan.org> - 3.37-1
- Update to 3.37
  - Regex fix in CPAN RT#96575 required Perl 5.10; updated regex to be
    backwards compatible with Perl 5.8

* Fri Aug 14 2015 Paul Howarth <paul@city-fan.org> - 3.36-1
- Update to 3.36
  - Parsing fixes for fetch_hash and bodystructure + better handling of data
    containing escaped characters (CPAN RT#96575)
  - Fix hang waiting for tag if DONE sent outside of IDLE (CPAN RT#97718)
  - Failed literal commands hung waiting for '+' (CPAN RT#100683)
  - login() fails if username requires use of literals (CPAN RT#100601)
  - is_parent() should return undef on \NoInferiors (CPAN RT#103823)
  - fetch_hash fails if sequence number contains '*' (CPAN RT#105456)
  - No longer removing unrequested data (except UID) in returned hashes
  - Selectable broke in 3.29 due to \b around \NoSelect (CPAN RT#91912)
  - Some documentation, test cleanup and new tests
- Classify buildreqs by usage
- Add upstream fix for Perl 5.8 incompatible regex

* Fri Sep 12 2014 Paul Howarth <paul@city-fan.org> - 3.35-3
- Drop %%defattr, redundant since rpm 4.4

* Sat Nov 23 2013 Paul Howarth <paul@city-fan.org> - 3.35-1
- Update to 3.35
  - Use Quote() over Massage() to avoid stripping double quotes from arg
    - Removed constant NonFolderArg
    - May deprecate Massage() in a future release
  - _list_or_lsub failed to handle folder names with double quotes
    - Clean up Escaped_results()
    - New methods: Escaped_history() and _escaped_trans_data()
    - Removed method: _list_response_preprocess()
  - getacl on a folder returned as literal failed (CPAN RT#90315)
    - _read_line could remove extra space when literal data was received
  - Typo fixes (CPAN RT#89040)
- Update UTF8 patch

* Fri Sep 27 2013 Paul Howarth <paul@city-fan.org> - 3.34-1
- Update to 3.34
  - Make Makefile.PL use non-interactive and document test.txt usage
  - New attribute: Socketargs => [ (IO::Socket::.. args) ]
    - cleanup connect() to be more flexible with IO::Socket::* args
  - Untagged server data during send literal may cause client to hang
    - _send_line() needs '+' only to know it is OK to send LITERAL data
    - Created _response_code_sub() to simplify _get_response()
  - Remove internal "Folders" cache
  - Allow for RFC 6154 "IMAP LIST Extension for Special-Use Mailboxes"
    - New method: folders_hash()
    - Deprecate: xlist_folders(), xlist()

* Tue Jul 23 2013 Paul Howarth <paul@city-fan.org> - 3.33-2
- Perl 5.18 rebuild

* Tue May 14 2013 Paul Howarth <paul@city-fan.org> - 3.33-1
- Update to 3.33
  - More cleanup on use of $@ and $!
  - Clean up get_bodystructure and get_envelope
  - Allow Ssl arg as an arrayref to pass args to IO::Socket::SSL
  - No need to Massage() the folder name in uidnext()
  - get_envelope() fails when subject ends with backslash (CPAN RT#84028)
  - move()/copy() with sequence caused numeric warning (CPAN RT#79476)
  - move()/copy() no longer sort message(s) provided by caller

* Fri Aug 10 2012 Paul Howarth <paul@city-fan.org> - 3.32-1
- Update to 3.32
  - Document RFC2087 quota related calls
  - Fix idle/idle_data documentation error (CPAN RT#78474)
  - Quote()/Massage() now uses literals for non ASCII data
  - Use Quote()/Massage() consistently now in:
    login() proxyauth() deleteacl() setacl() listrights() rename()
  - Documented deleteacl() and other minor pod cleanup
  - Ran Mail::IMAPClient::BodyStructure through perltidy
  - Update year in README/pod to 2012
  - Fix CPAN RT#74733: Fails with Parse::RecDescent ≥ 1.966_002
  - Fix CPAN RT#74593: Recent changes break Module::ExtractUse and ...
  - Makefile.PL: avoid buggy Parse::RecDescent 1.966_002 until 1.967_009
  - Mail::IMAPClient::BodyStructure usage/docs updates (CPAN RT#76989)

* Tue Jul 10 2012 Paul Howarth <paul@city-fan.org> - 3.31-2
- BR: perl(base), perl(Carp), perl(constant), perl(File::Temp), perl(File::Spec),
  perl(List::Util) and perl(MIME::Base64)

* Tue Mar 20 2012 Paul Howarth <paul@city-fan.org> - 3.31-1
- Update to 3.31
  - Support for partial data responses in fetch_hash (CPAN RT#74799)
  - Cleaner handling of BODY.PEEK responses
  - Properly handle ALL|FULL|FAST fetch macros in fetch_hash
- Don't need to remove empty directories from buildroot
- Use a patch rather than scripted iconv to fix character encodings
- Drop support for distributions prior to FC-3:
  - Drop patch for Perl 5.8.0 support
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Sat Nov 12 2011 Paul Howarth <paul@city-fan.org> - 3.30-1
- Update to 3.30
  - StartTLS array ref argument dereferenced twice (CPAN RT#72347)
  - During connect(): Port now defaults 143 or 993 if $self->Ssl
  - Stop reconnect deep recursion if server disconnects on login
  - reconnect() now returns 1 on success; on error undef or 0=recursive
  - Handle EBADF from syswrite in _send_bytes
  - Add RFC4978 IMAP COMPRESS Extension support (CPAN RT#67263):
    - New method: compress()
    - New attributes: Compress Readmoremethod
  - General code cleanup:
    - new() now always returns $self or undef (never $sock any more)
    - Socket() now always return a socket or undef
    - login() now always return $self or undef
    - _read_more() will now use Readmoremethod if set
  - Missing second arg '' for encode_base64 causing AUTHENTICATE PLAIN to fail
    on lines longer than 76 characters
- BR/R: perl(Digest::MD5) for DIGEST-MD5 authentication support
- BR/R: perl(Compress::Zlib) for COMPRESS DEFLATE support

* Fri Aug 12 2011 Paul Howarth <paul@city-fan.org> - 3.29-1
- Update to 3.29
  - CPAN RT#69876: ENVELOPE as part of fetch_hash convenience method
  - Added Mail::IMAPClient::BodyStructure::Envelope->parse_string($str)
    convenience method for handling ENVELOPE data from fetch_hash
  - CPAN RT#68310: folders() should not call exists()/STATUS
  - Use selectable() instead of exists() in call
  - Ensure separator is set properly in folders()
  - selectable now properly checks for \Noselect flag
  - Update folders() POD to match implementation behaviour
  - CPAN RT#68648: CAPABILITY after authenticate
  - Delete cache after State set to Authenticate
  - State() is no longer an auto-generated method
  - CPAN RT#68755: Provided socket loses blocking in 3.19-3.28
- Install to vendor directories rather than perl directories

* Tue Jun 28 2011 Paul Howarth <paul@city-fan.org> - 3.28-2
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Sat Mar  5 2011 Paul Howarth <paul@city-fan.org> - 3.28-1
- Update to 3.28
  - CPAN RT#66004: internaldate() return undef if no internaldate in reply
  - CPAN RT#66367: multiple fixes for fetch_hash
  - Do not touch CRLF in Escape()/Unescape()
  - Added Escape() method
  - CPAN RT#66287: flags results truncated due to Maxcommandlength
  - CPAN RT#65694: SASL PLAIN: bad order of login data

* Tue Feb 15 2011 Paul Howarth <paul@city-fan.org> - 3.27-1
- Update to 3.27
  - CPAN RT#65694: Migrate fails
  - CPAN RT#65470: Uninitialized warning in message_to_file
  - CPAN RT#61835: (DOC) in LIST context undef may be returned, and warn/
    highlight behaviour in docs Errors section
  - Updated documentation
    - migrate() documentation fixed
    - Moved Custom Authentication Mechanisms toward end
    - Recommended use of scalar context due to historical API behaviour

* Tue Feb  1 2011 Paul Howarth <paul@city-fan.org> - 3.26-1
- Update to 3.26
  - See Changes for full details
  - Require Perl 5.8.1 as constant use is invalid on 5.6
  - Fix fetch_hash() parse errors (CPAN RT#63524)
  - Fix handling of LITERAL values in response
  - Fix handling of field names with a dash (e.g. X-SAVEDATE)
  - fetch_hash now uses Escaped_results() method
  - Fixed Escaped_results() to properly join LITERAL data with the data that
    comes before and after it
  - append_file() does not interpret $date as expected (CPAN RT#60945)
  - $date should now be 1 (to use the file mtime) or a valid RFC3501 date
  - Address memory consumption with message_string()/append() (CPAN RT#61292)
  - Major problem with one function in IMAPClient (CPAN RT#61806)
  - Significant memory usage improvements
  - Relax get_envelope(), allow empty reply-to (CPAN RT#63444)
  - append_string could invalidate a good $date (CPAN RT#61068)
  - Fix logout error if delay between BYE and tagged OK (CPAN RT#60045)
  - Fix migrate() errors (CPAN RT#61062)
  - Rewrite migrate() to be functional and simple
  - Update README and clean up several old or out of date files
- Upstream dropped COPYRIGHT file, so drop it from %%doc
- Install into perl directories rather than vendor directories
- Take Makefile.PL input from /dev/null rather than answer interactive questions
- Add patch to drop Perl version requirement to 5.8.0

* Sat Oct  2 2010 Paul Howarth <paul@city-fan.org> - 3.25-1
- Update to 3.25
  - See Changes for full details
  - CPAN RT#57661: uninitialized value warning in IMAPClient::thread
  - CPAN RT#57337: Correctly handle multiparts in BodyStructure.pm
  - CPAN RT#57659: install fails when using cPanel GUI

* Sat Oct  2 2010 Paul Howarth <paul@city-fan.org> - 3.24-1
- Update to 3.24
  - See Changes for full details
  - CPAN RT#48912: wrong part numbers in multipart messages
  - CPAN RT#55527: [no] disconnect during DESTROY
  - CPAN RT#55898: append_file can send too many bytes
  - CPAN RT#57048: _quote_search() using $_ in loop instead of $v
- Turn off exec bits in examples to avoid docfile dependencies

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 3.23-3
- Rebuild for perl 5.12.1 in Rawhide

* Fri May  7 2010 Paul Howarth <paul@city-fan.org> - 3.23-2
- Fix dist tag to work with RHEL6 Beta

* Tue Feb  9 2010 Paul Howarth <paul@city-fan.org> - 3.23-1
- Import from Fedora
- Update to 3.23

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 3.21-2
- Rebuild against perl 5.10.1

* Fri Sep 25 2009 Stepan Kasal <skasal@redhat.com> - 3.21-1
- New upstream source

* Sat Sep  5 2009 Stepan Kasal <skasal@redhat.com> - 3.20-1
- New upstream source

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.14-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Mar 13 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 3.14-1
- Update to 3.14

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.08-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jul 21 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 3.08-1
- 3.08

* Tue Mar 11 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 3.05-1
- 3.05

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.2.9-6
- Rebuild for perl 5.10 (again)

* Mon Jan 28 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.2.9-5
- Rebuild for new perl

* Sun Aug 26 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 2.2.9-4
- License tag fix

* Mon Apr  9 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 2.2.9-3
- Set examples as non-exec, fix intepreter

* Wed Apr  4 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 2.2.9-2
- Add docs/ and examples/ as %%doc

* Mon Apr  2 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 2.2.9-1
- Initial package for Fedora
